bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.plates_multiplier
=========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. autoattribute:: ExponentialFamily.plates_multiplier